@@ -2,5 +2,4 @@
 #
 # vim: expandtab shiftwidth=4 softtabstop=4
 #
-from . import *
-
+from oc import *
\ No newline at end of file
