@@ -17,11 +17,13 @@ import sys
 import time
 import xml.etree.ElementTree as ET
 from logging import debug,info
-
+import magic
 import requests
+import socket
+import getpass
 import six
 from six.moves.urllib import parse
-from . import exit_codes, progress, utils, exceptions
+from . import exit_codes, progress, utils, exceptions, pkg_info
 
 try:
     from concurrent.futures import ThreadPoolExecutor, Future
@@ -403,6 +405,7 @@ class Client(object):
         self.progress = kwargs.get('progress', False)
         self.progress_class = kwargs.get('progress_class', progress.ProgressCR)
         self.oc_path_format = kwargs.get('oc_path_format', False)
+        self.proxies = kwargs.get('proxies', None)
 
     def login(self, user_id, password):
         """Authenticate to ownCloud.
@@ -472,9 +475,14 @@ class Client(object):
         """
         returns true if the file exists, otherwise false
         """
+        headers = {}
+        headers['User-Agent'] = 'gtocclient/{} ({}; {})'.format(pkg_info.version, getpass.getuser(),
+                                                               socket.gethostname())
         res = self._session.request(
             'HEAD',
-            self._webdav_url + parse.quote(self._encode_string(path))
+            self._webdav_url + parse.quote(self._encode_string(path)),
+            proxies=self.proxies,
+            headers=headers
         )
         if res.status_code < 300:
             return True
@@ -669,7 +677,8 @@ class Client(object):
         """
         # if self.file_info(remote_path).file_type == "dir":
         #     raise Exception("远程路径为dir类型，无法上传")
-        return self._make_dav_request('PUT', remote_path, data=data, **kwargs)
+        mime_type = magic.from_buffer(data,mime=True)
+        return self._make_dav_request('PUT', remote_path, data=data, headers={'Content-Type':mime_type}, **kwargs)
 
     def put_file(self, remote_path, local_source_file, **kwargs):
         """Upload a file
@@ -716,8 +725,14 @@ class Client(object):
             )
 
         stat_result = os.stat(local_source_file)
-
+        if stat_result.st_size > 30*1024*1024*1024:
+            print("Error: Uploading files larger than 30G is not allowed.")
+            return
+        if stat_result.st_size > 20*1024*1024*1024:
+            print("Warn: Uploading files larger than 20G is not guaranteed to be stable. Please split it into a number of smaller files.")
         headers = {}
+        mime_type = magic.from_file(local_source_file, mime=True)
+        headers['Content-Type'] = mime_type
         if kwargs.get('keep_mtime', True):
             headers['X-OC-MTIME'] = str(int(stat_result.st_mtime))
 
@@ -836,6 +851,9 @@ class Client(object):
         file_handle.seek(0)
 
         headers = {}
+        mime_type = magic.from_file(local_source_file, mime=True)
+        headers['Content-Type'] = mime_type
+
         st_mtime = int(stat_result.st_mtime)
         if kwargs.get('keep_mtime', True):
             headers['X-OC-MTIME'] = str(st_mtime)
@@ -2039,9 +2057,11 @@ class Client(object):
         path = self.OCS_BASEPATH + service + slash + action
 
         attributes = kwargs.copy()
-
-        if 'headers' not in attributes:
-            attributes['headers'] = {}
+        attributes['headers'] = attributes.get('headers', {})
+        attributes['headers']['User-Agent'] = 'gtocclient/{} ({}; {})'.format(pkg_info.version, getpass.getuser(),
+                                                               socket.gethostname())
+        # if 'headers' not in attributes:
+        #     attributes['headers'] = {}
 
         attributes['headers']['OCS-APIREQUEST'] = 'true'
 
@@ -2049,7 +2069,7 @@ class Client(object):
             print('OCS request: %s %s %s' % (method, self.url + path,
                                              attributes))
 
-        res = self._session.request(method, self.url + path, **attributes)
+        res = self._session.request(method, self.url + path, proxies=self.proxies, **attributes)
         return res
 
     def _make_dav_request(self, method, path, **kwargs):
@@ -2062,6 +2082,9 @@ class Client(object):
         contains it, or True if the operation succeded, False
         if it didn't
         """
+        headers = kwargs.get('headers', {})
+        headers['User-Agent'] = 'gtocclient/{} ({}; {})'.format(pkg_info.version,getpass.getuser(),socket.gethostname())
+        kwargs['headers'] = headers
         if self._debug:
             print('DAV request: %s %s' % (method, path))
             if kwargs.get('headers'):
@@ -2071,6 +2094,7 @@ class Client(object):
         res = self._session.request(
             method,
             self._webdav_url + parse.quote(self._encode_string(path)),
+            proxies=self.proxies,
             **kwargs
         )
         if self._debug:
