@@ -243,18 +243,30 @@ def process_patterns(patterns_list, patterns_from, is_glob, option_txt = ""):
     return patterns_compiled, patterns_textual
 
 
-def test(args):
+def get_client(progress=True):
     cfg = Config()
-    client = Client(cfg.url, progress=cfg.progress_meter, progress_class=cfg.progress_class, oc_path_format=True)
+    proxies = None
+    if cfg.proxy_host and cfg.proxy_port > 0:
+        proxies = {
+            'http': '{}:{}'.format(cfg.proxy_host, cfg.proxy_port),
+            'https': '{}:{}'.format(cfg.proxy_host, cfg.proxy_port)
+        }
+    if progress:
+        client = Client(cfg.url, progress=cfg.progress_meter, progress_class=cfg.progress_class, oc_path_format=True, proxies=proxies)
+    else:
+        client = Client(cfg.url, oc_path_format=True, proxies=proxies)
     client.login(cfg.user_id, cfg.password)
+    return client
+
+
+def test(args):
+    client = get_client()
     client.copy("/DLP", "/tes/test")
 
 
 def cmd_info(args):
     destination = normalize_oc_path(args.pop())
-    cfg = Config()
-    client = Client(cfg.url, progress=cfg.progress_meter, progress_class=cfg.progress_class, oc_path_format=True)
-    client.login(cfg.user_id, cfg.password)
+    client = get_client()
     if not client.exists(destination):
         raise ParameterError("No such file or directory: %s" % format_oc_path_output(convert(destination)))
     props = client.file_info(destination, FileInfo.get_all_property_arguments())
@@ -358,8 +370,7 @@ Size              %(size)s'''
 
 def subcmd_mv_cp(source, destination_base, func):
     cfg = Config()
-    client = Client(cfg.url, progress=cfg.progress_meter, progress_class=cfg.progress_class, oc_path_format=True)
-    client.login(cfg.user_id, cfg.password)
+    client = get_client()
     if not client.exists(source):
         raise ParameterError("No such directory: %s" % format_oc_path_output(convert(source)))
     prop = client.file_info(source)
@@ -424,8 +435,7 @@ def cmd_mv(args):
 def cmd_rm(args):
     remote_path = normalize_oc_path(args.pop())
     cfg = Config()
-    client = Client(cfg.url, progress=cfg.progress_meter, progress_class=cfg.progress_class, oc_path_format=True)
-    client.login(cfg.user_id, cfg.password)
+    client = get_client()
     if not client.exists(remote_path):
         raise ParameterError("No such directory: %s" % format_oc_path_output(convert(remote_path)))
     prop = client.file_info(remote_path)
@@ -441,8 +451,7 @@ def cmd_rm(args):
 def cmd_rmdir(args):
     destination = normalize_oc_path(args.pop())
     cfg = Config()
-    client = Client(cfg.url, progress=cfg.progress_meter, progress_class=cfg.progress_class, oc_path_format=True)
-    client.login(cfg.user_id, cfg.password)
+    client = get_client()
     if not client.exists(destination):
         raise ParameterError("No such directory: %s" % format_oc_path_output(convert(destination)))
     props = client.file_info(destination)
@@ -458,8 +467,7 @@ def cmd_rmdir(args):
 def cmd_mkdir(args):
     destination = normalize_oc_path(args.pop())
     cfg = Config()
-    client = Client(cfg.url, progress=cfg.progress_meter, progress_class=cfg.progress_class, oc_path_format=True)
-    client.login(cfg.user_id, cfg.password)
+    client = get_client()
     if client.exists(destination):
         raise ParameterError("Remote path %s already exists. Give it a new name" % format_oc_path_output(convert(destination)))
     client.mkdir(destination)
@@ -469,8 +477,7 @@ def cmd_mkdir(args):
 def cmd_put(args):
     local_path = args[0]
     cfg = Config()
-    client = Client(cfg.url, progress=cfg.progress_meter, progress_class=cfg.progress_class, oc_path_format=True)
-    client.login(cfg.user_id, cfg.password)
+    client = get_client()
 
     if len(args) > 1:
         destination_base = normalize_oc_path(args.pop())
@@ -498,7 +505,7 @@ def cmd_put(args):
         try:
             client.put_file(destination_base, local_path, force=cfg.force, skip_existing=cfg.skip_existing,
                             put_continue=cfg.put_continue, chunked=cfg.chunked,
-                            chunked_size=cfg.chunk_size_mb*1024*1024, cache_valid_hour=cfg.cache_valid_hour)
+                            chunk_size=cfg.chunk_size_mb*1024*1024, cache_valid_hour=cfg.cache_valid_hour)
         except OCFileExistsError as e:
             raise ParameterError(
                 u"File %s already exists. Use either of --force or --skip-existing." % format_oc_path_output(convert(e.path)))
@@ -516,7 +523,7 @@ def cmd_put(args):
         try:
             client.put_directory(destination_base, local_path, force=cfg.force, skip_existing=cfg.skip_existing,
                                  put_continue=cfg.put_continue, chunked=cfg.chunked,
-                                 chunked_size=cfg.chunk_size_mb*1024*1024,cache_valid_hour=cfg.cache_valid_hour)
+                                 chunk_size=cfg.chunk_size_mb*1024*1024,cache_valid_hour=cfg.cache_valid_hour)
         except (OCFileExistsError, OCDirExistsError) as e:
             raise ParameterError(
                 u"%s already exists. Use either of --force or --skip-existing or --put-continue" % format_oc_path_output(convert(e.path)))
@@ -531,8 +538,7 @@ def cmd_put(args):
 def cmd_get(args):
     remote_path = normalize_oc_path(args[0])
     cfg = Config()
-    client = Client(cfg.url, progress=cfg.progress_meter, progress_class=cfg.progress_class, oc_path_format=True)
-    client.login(cfg.user_id, cfg.password)
+    client = get_client()
     props = client.file_info(remote_path)
     if len(args) > 1:
         destination_base = args.pop()
@@ -627,8 +633,7 @@ def cmd_la(args):
 
 def cmd_ls(args):
     cfg = Config()
-    client = Client(cfg.url, oc_path_format=True)
-    client.login(cfg.user_id,cfg.password)
+    client = get_client(progress=False)
     path = "/"
     if len(args) > 0:
         path = normalize_oc_path(args[0])
